..
    Copyright (C) 2022-2024 CERN.

    invenio-administration is free software; you can redistribute it and/or
    modify it under the terms of the MIT License; see LICENSE file for more
    details.

Changes
=======

Version 2.2.1 (released 2024-05-15)

- remove implicit dependency on oai_pmh view

Version 2.2.0 (released 2024-03-22)

- fix: before_first_request deprecation (move to finalize app entry point)
- installation: upgrade invenio-app and invenio-base

Version 2.1.1 (released 2024-03-04)

- bump react-invenio-forms

Version 2.1.0 (released 2024-02-27)

- actions: add explicit prop for dropdown display
- form: updated mapping and added RichInput

Version 2.0.1 (released 2024-02-19)

- Add default bool value for BooleanField

Version 2.0.0 (released 2024-01-29)

- installation: bump invenio-accounts

Version 1.10.1 (2023-12-07)

- format: enforce code formatting using black
- marshmallow_utils: enhance marshmallow utility functions to traverse type inheritance
- i18n-global: add fuzzy search in compile-catalog

Version 1.10.0 (2023-11-30)

- marshmallw_utils: add EDTFDateTimeString mapping

Version 1.9.3 (2023-10-30)

- marshmallow_utils: add ``URL`` field type mapping

Version 1.9.2 (2023-10-19)

- accessibility: add tooltips to icons

Version 1.9.1 (2023-09-25)

- assets: improve error handling on details page
- styling: minor improvements

Version 1.9.0 (2023-09-18)

- views: adapt actions creation

Version 1.8.0 (2023-09-14)

- setup: bump to invenio-vocabularies v2.0.0

Version 1.7.0 (2023-09-08)

- chore: expose admin api
- assets: overridable search result item layout
- utils: process date field in schema

Version 1.6.1 (2023-07-07)

- skip `fields.Method` from jsonify

Version 1.6.0 (2023-07-03)

- Adding a mapping for the fields.Method

Version 1.5.0 (2023-06-15)

- setup: upgrade invenio dependencies

Version 1.4.1 (2023-05-25)

- fix action form creation

Version 1.4.0 (2023-04-25)

- upgrade invenio-records-resources

Version 1.3.0 (2023-04-20)

- upgrade invenio-records-resources

Version 1.2.0 (2023-03-24)

- bump invenio-records-resources to v2.0.0

Version 1.1.1 (released 2023-03-09)

- assets: add html formatting to display components

Version 1.1.0 (released 2023-03-02)

- remove deprecated flask-babelex dependency and imports
- upgrade invenio-theme, invenio-vocabularies
- fix form field sorting order

Version 1.0.6 (released 2023-02-15)

- forms: add support for checkbox, dropdown and textarea fields
- forms: add support for default value (prefill)
- forms: add support for specific table column width (search view)

Version 1.0.5 (released 2023-01-26)

- assets: fix button help popup

Version 1.0.4 (released 2023-01-24)

- menu: add disable view hook method

Version 1.0.3 (released 2023-01-20)

- forms: add tooltip to field when passed from fieldSchema
- modal: fix styling

Version 1.0.2 (released 2022-11-25)

- use centralized axios configuration
- add i18n translations
- refactor actions buttons

Version 1.0.1 (released 2022-11-04)

- upgrade invenio-records-resources
- upgrade invenio-vocabublaries

Version 1.0.0

- Initial public release.
